
/*
	this code convert StringTable.h
*/


#define STRING_UTF8(x)  QString::fromUtf8(x)

/* for CMainWidget */

#define ID_STRING_00  "モバイル四川省"

//speed_menu
#define ID_STRING_01  "スピード"
#define ID_STRING_02  "とても遅い"
#define ID_STRING_03  "遅い"
#define ID_STRING_04  "ふつう"
#define ID_STRING_05  "速い"
#define ID_STRING_06  "とても速い"

//size_menu
#define ID_STRING_10  "サイズ"

// Difficulty
#define ID_STRING_20  "レベル"
#define ID_STRING_21  "簡単"
#define ID_STRING_22  "普通"
#define ID_STRING_23  "難しい"

//gravity
#define ID_STRING_30  "重力"
#define ID_STRING_31  "なし"
#define ID_STRING_32  "あり"

//game submenu
#define ID_STRING_100  "ゲーム"
#define ID_STRING_101  "新規"
#define ID_STRING_102  "ヒント"
#define ID_STRING_103  "元に戻す"
#define ID_STRING_104  "やり直す"
#define ID_STRING_105  "終了"

// setting submenu
#define ID_STRING_110  "詳細設定"

//time
#define ID_STRING_200 "プレイ時間"

//menu 
#define ID_STRING_1000  "ゲーム"
#define ID_STRING_1001  "設定"

//Messages
#define ID_STRING_2000  "ゲームオーバー"
#define ID_STRING_2001  "取れる牌が無くなりました。"

#define ID_STRING_2002  "クリア!!"
#define ID_STRING_2003  "全ての牌を取りました!\nクリア時間:%1"
#define ID_STRING_2004  "全ての牌を取りました!\nハイスコアに登録されました。\nクリア時間:%1"

//ScoreListDaialog
#define ID_STRING_2010 "ハイスコア"
#define ID_STRING_2011 "順位"
#define ID_STRING_2012 "クリアタイム"
#define ID_STRING_2013 "日付"



